lilypondnametools.LilyPondGrobOverride
======================================

.. abjad-lineage:: abjad.tools.lilypondnametools.LilyPondGrobOverride.LilyPondGrobOverride

.. autoclass:: abjad.tools.lilypondnametools.LilyPondGrobOverride.LilyPondGrobOverride

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.lilypondnametools.LilyPondGrobOverride.LilyPondGrobOverride.context_name
      ~abjad.tools.lilypondnametools.LilyPondGrobOverride.LilyPondGrobOverride.grob_name
      ~abjad.tools.lilypondnametools.LilyPondGrobOverride.LilyPondGrobOverride.is_once
      ~abjad.tools.lilypondnametools.LilyPondGrobOverride.LilyPondGrobOverride.is_revert
      ~abjad.tools.lilypondnametools.LilyPondGrobOverride.LilyPondGrobOverride.override_format_pieces
      ~abjad.tools.lilypondnametools.LilyPondGrobOverride.LilyPondGrobOverride.property_path
      ~abjad.tools.lilypondnametools.LilyPondGrobOverride.LilyPondGrobOverride.revert_format_pieces
      ~abjad.tools.lilypondnametools.LilyPondGrobOverride.LilyPondGrobOverride.value
      ~abjad.tools.lilypondnametools.LilyPondGrobOverride.LilyPondGrobOverride.__eq__
      ~abjad.tools.lilypondnametools.LilyPondGrobOverride.LilyPondGrobOverride.__format__
      ~abjad.tools.lilypondnametools.LilyPondGrobOverride.LilyPondGrobOverride.__hash__
      ~abjad.tools.lilypondnametools.LilyPondGrobOverride.LilyPondGrobOverride.__ne__
      ~abjad.tools.lilypondnametools.LilyPondGrobOverride.LilyPondGrobOverride.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.lilypondnametools.LilyPondGrobOverride.LilyPondGrobOverride.context_name
   :noindex:

.. autoattribute:: abjad.tools.lilypondnametools.LilyPondGrobOverride.LilyPondGrobOverride.grob_name
   :noindex:

.. autoattribute:: abjad.tools.lilypondnametools.LilyPondGrobOverride.LilyPondGrobOverride.is_once
   :noindex:

.. autoattribute:: abjad.tools.lilypondnametools.LilyPondGrobOverride.LilyPondGrobOverride.is_revert
   :noindex:

.. autoattribute:: abjad.tools.lilypondnametools.LilyPondGrobOverride.LilyPondGrobOverride.override_format_pieces
   :noindex:

.. autoattribute:: abjad.tools.lilypondnametools.LilyPondGrobOverride.LilyPondGrobOverride.property_path
   :noindex:

.. autoattribute:: abjad.tools.lilypondnametools.LilyPondGrobOverride.LilyPondGrobOverride.revert_format_pieces
   :noindex:

.. autoattribute:: abjad.tools.lilypondnametools.LilyPondGrobOverride.LilyPondGrobOverride.value
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.lilypondnametools.LilyPondGrobOverride.LilyPondGrobOverride.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondnametools.LilyPondGrobOverride.LilyPondGrobOverride.__format__
   :noindex:

.. automethod:: abjad.tools.lilypondnametools.LilyPondGrobOverride.LilyPondGrobOverride.__hash__
   :noindex:

.. automethod:: abjad.tools.lilypondnametools.LilyPondGrobOverride.LilyPondGrobOverride.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondnametools.LilyPondGrobOverride.LilyPondGrobOverride.__repr__
   :noindex:
